@@ -502,8 +502,8 @@ static const uint8_t iv_512[64] = {
 };
 
 void oqs_sha2_sha224_inc_init_c(sha224ctx *state) {
-	state->ctx = OQS_MEM_checked_malloc(PQC_SHA256CTX_BYTES);
-
+	state->ctx = OQS_MEM_malloc(PQC_SHA256CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(state->ctx, "SHA2");
 	for (size_t i = 0; i < 32; ++i) {
 		state->ctx[i] = iv_224[i];
 	}
@@ -516,8 +516,8 @@ void oqs_sha2_sha224_inc_init_c(sha224ctx *state) {
 
 void oqs_sha2_sha256_inc_init_c(sha256ctx *state) {
 	state->data_len = 0;
-	state->ctx = OQS_MEM_checked_malloc(PQC_SHA256CTX_BYTES);
-
+	state->ctx = OQS_MEM_malloc(PQC_SHA256CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(state->ctx, "SHA2");
 	for (size_t i = 0; i < 32; ++i) {
 		state->ctx[i] = iv_256[i];
 	}
@@ -529,8 +529,8 @@ void oqs_sha2_sha256_inc_init_c(sha256ctx *state) {
 }
 
 void oqs_sha2_sha384_inc_init_c(sha384ctx *state) {
-	state->ctx = OQS_MEM_checked_malloc(PQC_SHA512CTX_BYTES);
-
+	state->ctx = OQS_MEM_malloc(PQC_SHA512CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(state->ctx, "SHA2");
 	for (size_t i = 0; i < 64; ++i) {
 		state->ctx[i] = iv_384[i];
 	}
@@ -542,8 +542,8 @@ void oqs_sha2_sha384_inc_init_c(sha384ctx *state) {
 }
 
 void oqs_sha2_sha512_inc_init_c(sha512ctx *state) {
-	state->ctx = OQS_MEM_checked_malloc(PQC_SHA512CTX_BYTES);
-
+	state->ctx = OQS_MEM_malloc(PQC_SHA512CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(state->ctx, "SHA2");
 	for (size_t i = 0; i < 64; ++i) {
 		state->ctx[i] = iv_512[i];
 	}
@@ -555,32 +555,32 @@ void oqs_sha2_sha512_inc_init_c(sha512ctx *state) {
 }
 
 void oqs_sha2_sha224_inc_ctx_clone_c(sha224ctx *stateout, const sha224ctx *statein) {
-	stateout->ctx = OQS_MEM_checked_malloc(PQC_SHA256CTX_BYTES);
-
+	stateout->ctx = OQS_MEM_malloc(PQC_SHA256CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(stateout->ctx, "SHA2");
 	stateout->data_len = statein->data_len;
 	memcpy(stateout->data, statein->data, 128);
 	memcpy(stateout->ctx, statein->ctx, PQC_SHA256CTX_BYTES);
 }
 
 void oqs_sha2_sha256_inc_ctx_clone_c(sha256ctx *stateout, const sha256ctx *statein) {
-	stateout->ctx = OQS_MEM_checked_malloc(PQC_SHA256CTX_BYTES);
-
+	stateout->ctx = OQS_MEM_malloc(PQC_SHA256CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(stateout->ctx, "SHA2");
 	stateout->data_len = statein->data_len;
 	memcpy(stateout->data, statein->data, 128);
 	memcpy(stateout->ctx, statein->ctx, PQC_SHA256CTX_BYTES);
 }
 
 void oqs_sha2_sha384_inc_ctx_clone_c(sha384ctx *stateout, const sha384ctx *statein) {
-	stateout->ctx = OQS_MEM_checked_malloc(PQC_SHA512CTX_BYTES);
-
+	stateout->ctx = OQS_MEM_malloc(PQC_SHA512CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(stateout->ctx, "SHA2");
 	stateout->data_len = statein->data_len;
 	memcpy(stateout->data, statein->data, 128);
 	memcpy(stateout->ctx, statein->ctx, PQC_SHA512CTX_BYTES);
 }
 
 void oqs_sha2_sha512_inc_ctx_clone_c(sha512ctx *stateout, const sha512ctx *statein) {
-	stateout->ctx = OQS_MEM_checked_malloc(PQC_SHA512CTX_BYTES);
-
+	stateout->ctx = OQS_MEM_malloc(PQC_SHA512CTX_BYTES);
+	OQS_EXIT_IF_NULLPTR(stateout->ctx, "SHA2");
 	stateout->data_len = statein->data_len;
 	memcpy(stateout->data, statein->data, 128);
 	memcpy(stateout->ctx, statein->ctx, PQC_SHA512CTX_BYTES);
@@ -588,22 +588,22 @@ void oqs_sha2_sha512_inc_ctx_clone_c(sha512ctx *stateout, const sha512ctx *state
 
 /* Destroy the hash state. */
 void oqs_sha2_sha224_inc_ctx_release_c(sha224ctx *state) {
-	free(state->ctx); // IGNORE free-check
+	OQS_MEM_insecure_free(state->ctx);
 }
 
 /* Destroy the hash state. */
 void oqs_sha2_sha256_inc_ctx_release_c(sha256ctx *state) {
-	free(state->ctx); // IGNORE free-check
+	OQS_MEM_insecure_free(state->ctx);
 }
 
 /* Destroy the hash state. */
 void oqs_sha2_sha384_inc_ctx_release_c(sha384ctx *state) {
-	free(state->ctx); // IGNORE free-check
+	OQS_MEM_insecure_free(state->ctx);
 }
 
 /* Destroy the hash state. */
 void oqs_sha2_sha512_inc_ctx_release_c(sha512ctx *state) {
-	free(state->ctx); // IGNORE free-check
+	OQS_MEM_insecure_free(state->ctx);
 }
 
 void oqs_sha2_sha256_inc_blocks_c(sha256ctx *state, const uint8_t *in, size_t inblocks) {
@@ -614,8 +614,8 @@ void oqs_sha2_sha256_inc_blocks_c(sha256ctx *state, const uint8_t *in, size_t in
 
 	/*  Process any existing incremental data first */
 	if (state->data_len) {
-		tmp_in = OQS_MEM_checked_malloc(tmp_buflen);
-
+		tmp_in = OQS_MEM_malloc(tmp_buflen);
+		OQS_EXIT_IF_NULLPTR(tmp_in, "SHA2");
 		memcpy(tmp_in, state->data, state->data_len);
 		memcpy(tmp_in + state->data_len, in, tmp_buflen - state->data_len);
 
@@ -691,8 +691,8 @@ void oqs_sha2_sha256_inc_finalize_c(uint8_t *out, sha256ctx *state, const uint8_
 	if (new_inlen == inlen) {
 		new_in = in;
 	} else { //Combine incremental data with final input
-		tmp_in = OQS_MEM_checked_malloc(tmp_len);
-
+		tmp_in = OQS_MEM_malloc(tmp_len);
+		OQS_EXIT_IF_NULLPTR(tmp_in, "SHA2");
 		memcpy(tmp_in, state->data, state->data_len);
 		if (in && inlen) {
 			memcpy(tmp_in + state->data_len, in, inlen);
